messagingapp/msgappfw/server/inc/ccsconversation.h
changeset 25 84d9eb65b26f
parent 23 238255e8b033
child 37 518b245aa84c
child 47 5b14749788d7
--- a/messagingapp/msgappfw/server/inc/ccsconversation.h	Fri Apr 16 14:56:15 2010 +0300
+++ b/messagingapp/msgappfw/server/inc/ccsconversation.h	Mon May 03 12:29:07 2010 +0300
@@ -68,28 +68,12 @@
     void SetConversationId(TCsConversationEntryID aCsConversationEntryID);
 
     /**
      * GetFirstName
      * Returns the first name of the Conversation
      * 
      * @return First name of conversation
      */
-    HBufC* GetFirstName() const;
-
-    /**
-     * GetLastName
-     * Returns the last name of this Conversation
-     * 
-     * @return last name of conversation
-     */
-    HBufC* GetLastName() const;
-
-    /**
-     * GetNickName
-     * Returns the nick name of this Conversation
-     * 
-     * @return nick name of conversation
-     */
-    HBufC* GetNickName() const;
+    HBufC* GetDisplayName() const;
 
     /**
      * GetContactId
@@ -98,6 +82,7 @@
      * 
      * @return - integer type contact Id
      */
+    
     TInt32 GetContactId() const;
 
     /**
@@ -152,8 +137,9 @@
      * @param aFirstName first name
      * @param aLastName last name
      */
-    void AddContactDetailsL(TInt32 aContactId, const TDesC& aFirstName,
-                            const TDesC& aLastName, const TDesC& aNickName);
+    void AddContactDetailsL(
+            TInt32 aContactId, 
+            const TDesC& aDisplayName);
 
     /**
      * AddContactDetailsL
@@ -68,28 +68,12 @@
 
     /**
-     * GetFirstName
-     * Returns the first name of the Conversation
+     * GetDisplayName
+     * Returns the display name of the Conversation
      * 
      * @return First name of conversation